@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,15 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.managedidentities_v1.services.managed_identities_service import pagers
-from google.cloud.managedidentities_v1.types import managed_identities_service
-from google.cloud.managedidentities_v1.types import resource
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import ManagedIdentitiesServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ManagedIdentitiesServiceGrpcAsyncIOTransport
+
+from google.cloud.managedidentities_v1.services.managed_identities_service import pagers
+from google.cloud.managedidentities_v1.types import managed_identities_service, resource
+
 from .client import ManagedIdentitiesServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, ManagedIdentitiesServiceTransport
+from .transports.grpc_asyncio import ManagedIdentitiesServiceGrpcAsyncIOTransport
 
 
 class ManagedIdentitiesServiceAsyncClient:
@@ -267,9 +268,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_create_microsoft_ad_domain():
+            async def sample_create_microsoft_ad_domain():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 domain = managedidentities_v1.Domain()
@@ -288,7 +289,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -381,7 +382,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -411,9 +417,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_reset_admin_password():
+            async def sample_reset_admin_password():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = managedidentities_v1.ResetAdminPasswordRequest(
@@ -421,7 +427,7 @@ class ManagedIdentitiesServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.reset_admin_password(request=request)
+                response = await client.reset_admin_password(request=request)
 
                 # Handle the response
                 print(response)
@@ -481,7 +487,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -501,9 +512,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_list_domains():
+            async def sample_list_domains():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = managedidentities_v1.ListDomainsRequest(
@@ -514,7 +525,7 @@ class ManagedIdentitiesServiceAsyncClient:
                 page_result = client.list_domains(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -575,12 +586,20 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDomainsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -601,9 +620,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_get_domain():
+            async def sample_get_domain():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = managedidentities_v1.GetDomainRequest(
@@ -611,7 +630,7 @@ class ManagedIdentitiesServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_domain(request=request)
+                response = await client.get_domain(request=request)
 
                 # Handle the response
                 print(response)
@@ -671,7 +690,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -692,9 +716,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_update_domain():
+            async def sample_update_domain():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 domain = managedidentities_v1.Domain()
@@ -711,7 +735,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -791,7 +815,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -819,9 +848,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_delete_domain():
+            async def sample_delete_domain():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = managedidentities_v1.DeleteDomainRequest(
@@ -833,7 +862,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -906,7 +935,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -935,9 +969,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_attach_trust():
+            async def sample_attach_trust():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 trust = managedidentities_v1.Trust()
@@ -957,7 +991,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1028,7 +1062,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1058,9 +1097,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_reconfigure_trust():
+            async def sample_reconfigure_trust():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = managedidentities_v1.ReconfigureTrustRequest(
@@ -1074,7 +1113,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1158,7 +1197,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1187,9 +1231,9 @@ class ManagedIdentitiesServiceAsyncClient:
 
             from google.cloud import managedidentities_v1
 
-            def sample_detach_trust():
+            async def sample_detach_trust():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 trust = managedidentities_v1.Trust()
@@ -1209,7 +1253,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1282,7 +1326,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1309,14 +1358,13 @@ class ManagedIdentitiesServiceAsyncClient:
         reachable, and that the target domain is able to accept
         incoming trust requests.
 
-
         .. code-block:: python
 
             from google.cloud import managedidentities_v1
 
-            def sample_validate_trust():
+            async def sample_validate_trust():
                 # Create a client
-                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+                client = managedidentities_v1.ManagedIdentitiesServiceAsyncClient()
 
                 # Initialize request argument(s)
                 trust = managedidentities_v1.Trust()
@@ -1336,7 +1384,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1409,7 +1457,12 @@ class ManagedIdentitiesServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
